camelot.camelot.view.export.outlook

Package camelot :: Package camelot :: Package view :: Package export :: Module outlook |
[hide private]
[frames] | no frames]

# Module outlook

source code

Functions | [hide private]
open_html_in_outlook(html) | source code

Variables | [hide private]
| logger = `logging.getLogger('camelot.view.export.outlook')` Functions to send files by email using outlook

Variables Details | [hide private]

  ### logger Functions to send files by email using outlook After http://win32com.goermezer.de/content/view/227/192/ Value:
      logging.getLogger('camelot.view.export.outlook')